@@ -56,18 +56,12 @@ import           Control.Concurrent.MVar    (newMVar, withMVar)
 import           Control.Monad              (liftM, void, when)
 import           Control.Monad.IO.Class     (liftIO)
 import           Data.Int                   (Int64)
-import           Data.IORef                 (atomicModifyIORef, modifyIORef,
-                                             newIORef, readIORef, writeIORef)
+import           Data.IORef                 (atomicModifyIORef, modifyIORef, newIORef, readIORef, writeIORef)
 import           Data.Maybe                 (isJust)
-import           Prelude                    hiding (all, any, drop, filter,
-                                             map, mapM, mapM_, maximum,
-                                             minimum, read, take, unzip, zip,
-                                             zipWith)
+import           Prelude                    hiding (all, any, drop, filter, map, mapM, mapM_, maximum, minimum, read, take, unzip, zip, zipWith)
 ------------------------------------------------------------------------------
-import           System.IO.Streams.Internal (InputStream (..), OutputStream,
-                                             fromGenerator, makeInputStream,
-                                             makeOutputStream, read, unRead,
-                                             write, yield)
+import           System.IO.Streams.Internal (InputStream (..), OutputStream, fromGenerator, makeInputStream, makeOutputStream, read, unRead, write, yield)
+
 
 ------------------------------------------------------------------------------
 -- | A side-effecting fold over an 'OutputStream', as a stream transformer.
